==> jc-1.4.0.tar.gz: javax/xml/transform/OutputKeys.h <==
// public class javax.xml.transform.OutputKeys

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d174c6a194b13b5 javax_xml_transform_OutputKeys

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_OutputKeys_H_
#define _JC_javax_xml_transform_OutputKeys_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_transform_OutputKeys$sub_refs	_jc_javax_xml_transform_OutputKeys$sub_refs;
typedef struct _jc_javax_xml_transform_OutputKeys$sub_nonrefs	_jc_javax_xml_transform_OutputKeys$sub_nonrefs;
typedef struct _jc_javax_xml_transform_OutputKeys$refs	_jc_javax_xml_transform_OutputKeys$refs;
typedef struct _jc_javax_xml_transform_OutputKeys$nonrefs	_jc_javax_xml_transform_OutputKeys$nonrefs;
typedef struct _jc_javax_xml_transform_OutputKeys$object	_jc_javax_xml_transform_OutputKeys$object;

typedef struct _jc_javax_xml_transform_OutputKeys$fields_struct	_jc_javax_xml_transform_OutputKeys$fields_struct;
typedef const struct _jc_javax_xml_transform_OutputKeys$vmethods	_jc_javax_xml_transform_OutputKeys$vmethods;
typedef const struct _jc_javax_xml_transform_OutputKeys$vtable	_jc_javax_xml_transform_OutputKeys$vtable;
typedef const struct _jc_javax_xml_transform_OutputKeys$vtype	_jc_javax_xml_transform_OutputKeys$vtype;

// Class fields structure
struct _jc_javax_xml_transform_OutputKeys$fields_struct {
	struct _jc_java_lang_String$object	*CDATA__5fSECTION__5fELEMENTS;
	struct _jc_java_lang_String$object	*DOCTYPE__5fPUBLIC;
	struct _jc_java_lang_String$object	*DOCTYPE__5fSYSTEM;
	struct _jc_java_lang_String$object	*ENCODING;
	struct _jc_java_lang_String$object	*INDENT;
	struct _jc_java_lang_String$object	*MEDIA__5fTYPE;
	struct _jc_java_lang_String$object	*METHOD;
	struct _jc_java_lang_String$object	*OMIT__5fXML__5fDECLARATION;
	struct _jc_java_lang_String$object	*STANDALONE;
	struct _jc_java_lang_String$object	*VERSION;
};
extern _jc_javax_xml_transform_OutputKeys$fields_struct _jc_javax_xml_transform_OutputKeys$class_fields;

// Constructors
extern void _jc_javax_xml_transform_OutputKeys$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_OutputKeys$object *);

// Virtual methods structure
struct _jc_javax_xml_transform_OutputKeys$vmethods {
};

// Vtable
struct _jc_javax_xml_transform_OutputKeys$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_OutputKeys$vmethods	javax_xml_transform_OutputKeys;
};

// Vtype
struct _jc_javax_xml_transform_OutputKeys$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_OutputKeys$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_OutputKeys$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_OutputKeys$refs {
    _jc_javax_xml_transform_OutputKeys$sub_refs	javax_xml_transform_OutputKeys;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_OutputKeys$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_OutputKeys$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_OutputKeys$sub_nonrefs	javax_xml_transform_OutputKeys;
};

// Object instance structure
struct _jc_javax_xml_transform_OutputKeys$object {
	_jc_javax_xml_transform_OutputKeys$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_OutputKeys$vtype	*vtype;
	_jc_javax_xml_transform_OutputKeys$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_OutputKeys$vtype _jc_javax_xml_transform_OutputKeys$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_OutputKeys, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_OutputKeys$class_object;

#endif	/* _JC_javax_xml_transform_OutputKeys_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/OutputKeys.h <==
// public class javax.xml.transform.OutputKeys

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d174c6a194b13b5 javax_xml_transform_OutputKeys

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_transform_OutputKeys_H_
#define _JC_javax_xml_transform_OutputKeys_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_transform_OutputKeys$sub_refs	_jc_javax_xml_transform_OutputKeys$sub_refs;
typedef struct _jc_javax_xml_transform_OutputKeys$sub_nonrefs	_jc_javax_xml_transform_OutputKeys$sub_nonrefs;
typedef struct _jc_javax_xml_transform_OutputKeys$refs	_jc_javax_xml_transform_OutputKeys$refs;
typedef struct _jc_javax_xml_transform_OutputKeys$nonrefs	_jc_javax_xml_transform_OutputKeys$nonrefs;
typedef struct _jc_javax_xml_transform_OutputKeys$object	_jc_javax_xml_transform_OutputKeys$object;

typedef struct _jc_javax_xml_transform_OutputKeys$fields_struct	_jc_javax_xml_transform_OutputKeys$fields_struct;
typedef const struct _jc_javax_xml_transform_OutputKeys$vmethods	_jc_javax_xml_transform_OutputKeys$vmethods;
typedef const struct _jc_javax_xml_transform_OutputKeys$vtable	_jc_javax_xml_transform_OutputKeys$vtable;
typedef const struct _jc_javax_xml_transform_OutputKeys$vtype	_jc_javax_xml_transform_OutputKeys$vtype;

// Class fields structure
struct _jc_javax_xml_transform_OutputKeys$fields_struct {
	struct _jc_java_lang_String$object	*CDATA__5fSECTION__5fELEMENTS;
	struct _jc_java_lang_String$object	*DOCTYPE__5fPUBLIC;
	struct _jc_java_lang_String$object	*DOCTYPE__5fSYSTEM;
	struct _jc_java_lang_String$object	*ENCODING;
	struct _jc_java_lang_String$object	*INDENT;
	struct _jc_java_lang_String$object	*MEDIA__5fTYPE;
	struct _jc_java_lang_String$object	*METHOD;
	struct _jc_java_lang_String$object	*OMIT__5fXML__5fDECLARATION;
	struct _jc_java_lang_String$object	*STANDALONE;
	struct _jc_java_lang_String$object	*VERSION;
};
extern _jc_javax_xml_transform_OutputKeys$fields_struct _jc_javax_xml_transform_OutputKeys$class_fields;

// Constructors
extern void _jc_javax_xml_transform_OutputKeys$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_OutputKeys$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_transform_OutputKeys$vmethods {
};

// Vtable
struct _jc_javax_xml_transform_OutputKeys$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_transform_OutputKeys$vmethods	javax_xml_transform_OutputKeys;
};

// Vtype
struct _jc_javax_xml_transform_OutputKeys$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_OutputKeys$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_OutputKeys$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_OutputKeys$refs {
    _jc_javax_xml_transform_OutputKeys$sub_refs	javax_xml_transform_OutputKeys;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_OutputKeys$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_OutputKeys$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_transform_OutputKeys$sub_nonrefs	javax_xml_transform_OutputKeys;
};

// Object instance structure
struct _jc_javax_xml_transform_OutputKeys$object {
	_jc_javax_xml_transform_OutputKeys$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_OutputKeys$vtype	*vtype;
	_jc_javax_xml_transform_OutputKeys$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_OutputKeys$vtype _jc_javax_xml_transform_OutputKeys$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_OutputKeys, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_OutputKeys$class_object;

#endif	/* _JC_javax_xml_transform_OutputKeys_H_ */
